pub fn ContainedBy(
V0: FXMVECTOR,
V1: FXMVECTOR,
V2: FXMVECTOR,
Plane0: GXMVECTOR,
Plane1: HXMVECTOR,
Plane2: HXMVECTOR,
Plane3: CXMVECTOR<'_>,
Plane4: CXMVECTOR<'_>,
Plane5: CXMVECTOR<'_>,
) -> ContainmentTypeExpand description
Test a triangle vs 6 planes (typically forming a frustum).
Parameters
V0 A vector defining the triangle.
V1 A vector defining the triangle.
V2 A vector defining the triangle.
Plane0 A vector defining a plane.
Plane1 A vector defining a plane.
Plane2 A vector defining a plane.
Plane3 A vector defining a plane.
Plane4 A vector defining a plane.
Plane5 A vector defining a plane.
Return value
A ContainmentType value indicating whether the triangle is contained within the planes.
Remarks
Typically the six planes passed to this function represent a frustum.
Reference
https://docs.microsoft.com/en-us/windows/win32/api/directxcollision/nf-directxcollision-containedby