pub fn XMVectorMergeZW(V1: FXMVECTOR, V2: FXMVECTOR) -> XMVECTORExpand description
Creates a new vector by combining the z and w-components of two vectors.
Parameters
V1 First vector.
V2 Second vector.
Return value
Returns the merged vector.
Remarks
The following pseudocode demonstrates the operation of the function:
XMVECTOR Result;
Result.x = V1.z;
Result.y = V2.z;
Result.z = V1.w;
Result.w = V2.w;
return Result;Reference
https://docs.microsoft.com/en-us/windows/win32/api/directxmath/nf-directxmath-XMVectorMergeZW