XMVectorSplatY

Function XMVectorSplatY 

pub fn XMVectorSplatY(V: FXMVECTOR) -> XMVECTOR
Replicates the y component of a vector to all of the components.

Parameters

V Vector from which to select the y component.

Return value

Returns a vector, all of whose components are equal to the y component of V.

Reference

https://docs.microsoft.com/en-us/windows/win32/api/directxmath/nf-directxmath-XMVectorSplatY